package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.params.DESParameters;
import cn.com.infosec.crypto.params.KeyParameter;
import cn.com.infosec.crypto.params.ParametersWithIV;
import java.security.InvalidKeyException;
import java.security.spec.InvalidKeySpecException;
import java.security.spec.KeySpec;
import javax.crypto.SecretKey;
import javax.crypto.SecretKeyFactorySpi;
import javax.crypto.spec.DESKeySpec;
import javax.crypto.spec.DESedeKeySpec;
import javax.crypto.spec.PBEKeySpec;
import javax.crypto.spec.SecretKeySpec;

public class JCESecretKeyFactory extends SecretKeyFactorySpi implements PBE {
   // $FF: synthetic field
   static Class class$0;
   // $FF: synthetic field
   static Class class$1;
   // $FF: synthetic field
   static Class class$2;
   protected String algName;
   protected DERObjectIdentifier algOid;

   protected JCESecretKeyFactory(String algName, DERObjectIdentifier algOid) {
      this.algName = algName;
      this.algOid = algOid;
   }

   protected SecretKey engineGenerateSecret(KeySpec keySpec) {
      if (keySpec instanceof SecretKeySpec) {
         return (SecretKey)keySpec;
      } else {
         throw new InvalidKeySpecException("Invalid KeySpec");
      }
   }

   protected KeySpec engineGetKeySpec(SecretKey param1, Class param2) {
      // $FF: Couldn't be decompiled
   }

   protected SecretKey engineTranslateKey(SecretKey key) {
      if (key != null) {
         if (key.getAlgorithm().equalsIgnoreCase(this.algName)) {
            JCESecretKeyFactory var10002 = this;
            byte[] var2 = key.getEncoded();
            return new SecretKeySpec(var2, var10002.algName);
         } else {
            throw new InvalidKeyException("Key not of type " + this.algName + ".");
         }
      } else {
         throw new InvalidKeyException("key parameter is null");
      }
   }

   public static class DES extends JCESecretKeyFactory {
      public DES() {
         super("DES", (DERObjectIdentifier)null);
      }

      protected SecretKey engineGenerateSecret(KeySpec keySpec) {
         if (keySpec instanceof DESKeySpec) {
            DESKeySpec var2 = (DESKeySpec)keySpec;
            return new SecretKeySpec(var2.getKey(), "DES");
         } else {
            return super.engineGenerateSecret(keySpec);
         }
      }
   }

   public static class DESPBEKeyFactory extends JCESecretKeyFactory {
      private boolean forCipher;
      private int scheme;
      private int digest;
      private int keySize;
      private int ivSize;

      public DESPBEKeyFactory(String algorithm, DERObjectIdentifier oid, boolean forCipher, int scheme, int digest, int keySize, int ivSize) {
         super(algorithm, oid);
         this.forCipher = forCipher;
         this.scheme = scheme;
         this.digest = digest;
         this.keySize = keySize;
         this.ivSize = ivSize;
      }

      protected SecretKey engineGenerateSecret(KeySpec keySpec) {
         if (keySpec instanceof PBEKeySpec) {
            int var3;
            int var4;
            int var5;
            int var6;
            String var8;
            PBEKeySpec keySpec1;
            DESPBEKeyFactory var10002;
            DESPBEKeyFactory var10003;
            DESPBEKeyFactory var10004;
            DESPBEKeyFactory var10005;
            DESPBEKeyFactory var10006;
            if ((keySpec1 = (PBEKeySpec)keySpec).getSalt() == null) {
               var10002 = this;
               var10003 = this;
               var10004 = this;
               var10005 = this;
               var10006 = this;
               var8 = super.algName;
               DERObjectIdentifier var11 = var10006.algOid;
               var3 = var10005.scheme;
               var4 = var10004.digest;
               var5 = var10003.keySize;
               var6 = var10002.ivSize;
               return new JCEPBEKey(var8, var11, var3, var4, var5, var6, keySpec1, (CipherParameters)null);
            } else {
               int var2;
               CipherParameters var10;
               if (this.forCipher) {
                  var2 = this.scheme;
                  var3 = this.digest;
                  var4 = this.keySize;
                  var5 = this.ivSize;
                  var10 = PBE.Util.makePBEParameters(keySpec1, var2, var3, var4, var5);
               } else {
                  var2 = this.scheme;
                  var3 = this.digest;
                  var4 = this.keySize;
                  var10 = PBE.Util.makePBEMacParameters(keySpec1, var2, var3, var4);
               }

               if (var10 instanceof ParametersWithIV) {
                  DESParameters.setOddParity(((KeyParameter)((ParametersWithIV)var10).getParameters()).getKey());
               } else {
                  DESParameters.setOddParity(((KeyParameter)var10).getKey());
               }

               var10002 = this;
               var10003 = this;
               var10004 = this;
               var10005 = this;
               var10006 = this;
               var8 = super.algName;
               DERObjectIdentifier var12 = var10006.algOid;
               var4 = var10005.scheme;
               var5 = var10004.digest;
               var6 = var10003.keySize;
               int var7 = var10002.ivSize;
               return new JCEPBEKey(var8, var12, var4, var5, var6, var7, keySpec1, var10);
            }
         } else {
            throw new InvalidKeySpecException("Invalid KeySpec");
         }
      }
   }

   public static class DESede extends JCESecretKeyFactory {
      public DESede() {
         super("DESede", (DERObjectIdentifier)null);
      }

      protected KeySpec engineGetKeySpec(SecretKey key, Class keySpec) {
         if (keySpec == null) {
            throw new InvalidKeySpecException("keySpec parameter is null");
         } else if (key != null) {
            Class var3;
            Class var10000;
            if ((var3 = JCESecretKeyFactory.class$0) == null) {
               try {
                  var10000 = Class.forName("javax.crypto.spec.SecretKeySpec");
               } catch (ClassNotFoundException var5) {
                  throw new NoClassDefFoundError(var5.getMessage());
               }

               var3 = var10000;
               JCESecretKeyFactory.class$0 = var10000;
            }

            byte[] var11;
            if (var3.isAssignableFrom(keySpec)) {
               DESede var17 = this;
               var11 = key.getEncoded();
               return new SecretKeySpec(var11, var17.algName);
            } else {
               Class var10;
               if ((var10 = JCESecretKeyFactory.class$1) == null) {
                  try {
                     var10000 = Class.forName("javax.crypto.spec.DESedeKeySpec");
                  } catch (ClassNotFoundException var4) {
                     throw new NoClassDefFoundError(var4.getMessage());
                  }

                  var10 = var10000;
                  JCESecretKeyFactory.class$1 = var10000;
               }

               if (var10.isAssignableFrom(keySpec)) {
                  byte[] var13 = var11 = key.getEncoded();

                  Exception var14;
                  label60: {
                     int var15;
                     boolean var10001;
                     try {
                        var15 = var13.length;
                     } catch (Exception var9) {
                        var14 = var9;
                        var10001 = false;
                        break label60;
                     }

                     if (var15 == 16) {
                        label75: {
                           byte[] var16;
                           byte[] var10002;
                           try {
                              var13 = var11;
                              var16 = var11;
                              var10002 = new byte[24];
                           } catch (Exception var7) {
                              var14 = var7;
                              var10001 = false;
                              break label75;
                           }

                           var11 = var10002;

                           try {
                              System.arraycopy(var16, 0, var11, 0, 16);
                              System.arraycopy(var13, 0, var11, 16, 8);
                              return new DESedeKeySpec(var11);
                           } catch (Exception var6) {
                              var14 = var6;
                              var10001 = false;
                           }
                        }
                     } else {
                        try {
                           return new DESedeKeySpec(var11);
                        } catch (Exception var8) {
                           var14 = var8;
                           var10001 = false;
                        }
                     }
                  }

                  Exception var12 = var14;
                  throw new InvalidKeySpecException(var12.toString());
               } else {
                  throw new InvalidKeySpecException("Invalid KeySpec");
               }
            }
         } else {
            throw new InvalidKeySpecException("key parameter is null");
         }
      }

      protected SecretKey engineGenerateSecret(KeySpec keySpec) {
         if (keySpec instanceof DESedeKeySpec) {
            DESedeKeySpec var2 = (DESedeKeySpec)keySpec;
            return new SecretKeySpec(var2.getKey(), "DESede");
         } else {
            return super.engineGenerateSecret(keySpec);
         }
      }
   }

   public static class PBEKeyFactory extends JCESecretKeyFactory {
      private boolean forCipher;
      private int scheme;
      private int digest;
      private int keySize;
      private int ivSize;

      public PBEKeyFactory(String algorithm, DERObjectIdentifier oid, boolean forCipher, int scheme, int digest, int keySize, int ivSize) {
         super(algorithm, oid);
         this.forCipher = forCipher;
         this.scheme = scheme;
         this.digest = digest;
         this.keySize = keySize;
         this.ivSize = ivSize;
      }

      protected SecretKey engineGenerateSecret(KeySpec keySpec) {
         if (keySpec instanceof PBEKeySpec) {
            int var3;
            int var4;
            int var5;
            int var6;
            String var8;
            PBEKeySpec keySpec1;
            PBEKeyFactory var10002;
            PBEKeyFactory var10003;
            PBEKeyFactory var10004;
            PBEKeyFactory var10005;
            PBEKeyFactory var10006;
            if ((keySpec1 = (PBEKeySpec)keySpec).getSalt() == null) {
               var10002 = this;
               var10003 = this;
               var10004 = this;
               var10005 = this;
               var10006 = this;
               var8 = super.algName;
               DERObjectIdentifier var11 = var10006.algOid;
               var3 = var10005.scheme;
               var4 = var10004.digest;
               var5 = var10003.keySize;
               var6 = var10002.ivSize;
               return new JCEPBEKey(var8, var11, var3, var4, var5, var6, keySpec1, (CipherParameters)null);
            } else {
               int var2;
               CipherParameters var10;
               if (this.forCipher) {
                  var2 = this.scheme;
                  var3 = this.digest;
                  var4 = this.keySize;
                  var5 = this.ivSize;
                  var10 = PBE.Util.makePBEParameters(keySpec1, var2, var3, var4, var5);
               } else {
                  var2 = this.scheme;
                  var3 = this.digest;
                  var4 = this.keySize;
                  var10 = PBE.Util.makePBEMacParameters(keySpec1, var2, var3, var4);
               }

               var10002 = this;
               var10003 = this;
               var10004 = this;
               var10005 = this;
               var10006 = this;
               var8 = super.algName;
               DERObjectIdentifier var12 = var10006.algOid;
               var4 = var10005.scheme;
               var5 = var10004.digest;
               var6 = var10003.keySize;
               int var7 = var10002.ivSize;
               return new JCEPBEKey(var8, var12, var4, var5, var6, var7, keySpec1, var10);
            }
         } else {
            throw new InvalidKeySpecException("Invalid KeySpec");
         }
      }
   }

   public static class PBEWithMD2AndDES extends DESPBEKeyFactory {
      public PBEWithMD2AndDES() {
         super("PBEwithMD2andDES", PKCSObjectIdentifiers.pbeWithMD2AndDES_CBC, true, 0, 5, 64, 64);
      }
   }

   public static class PBEWithMD2AndRC2 extends PBEKeyFactory {
      public PBEWithMD2AndRC2() {
         super("PBEwithMD2andRC2", PKCSObjectIdentifiers.pbeWithMD2AndRC2_CBC, true, 0, 5, 64, 64);
      }
   }

   public static class PBEWithMD5And128BitAESCBCOpenSSL extends PBEKeyFactory {
      public PBEWithMD5And128BitAESCBCOpenSSL() {
         super("PBEWithMD5And128BitAES-CBC-OpenSSL", (DERObjectIdentifier)null, true, 3, 0, 128, 128);
      }
   }

   public static class PBEWithMD5And192BitAESCBCOpenSSL extends PBEKeyFactory {
      public PBEWithMD5And192BitAESCBCOpenSSL() {
         super("PBEWithMD5And192BitAES-CBC-OpenSSL", (DERObjectIdentifier)null, true, 3, 0, 192, 128);
      }
   }

   public static class PBEWithMD5And256BitAESCBCOpenSSL extends PBEKeyFactory {
      public PBEWithMD5And256BitAESCBCOpenSSL() {
         super("PBEWithMD5And256BitAES-CBC-OpenSSL", (DERObjectIdentifier)null, true, 3, 0, 256, 128);
      }
   }

   public static class PBEWithMD5AndDES extends DESPBEKeyFactory {
      public PBEWithMD5AndDES() {
         super("PBEwithMD5andDES", PKCSObjectIdentifiers.pbeWithMD5AndDES_CBC, true, 0, 0, 64, 64);
      }
   }

   public static class PBEWithMD5AndRC2 extends PBEKeyFactory {
      public PBEWithMD5AndRC2() {
         super("PBEwithMD5andRC2", PKCSObjectIdentifiers.pbeWithMD5AndRC2_CBC, true, 0, 0, 64, 64);
      }
   }

   public static class PBEWithRIPEMD160 extends PBEKeyFactory {
      public PBEWithRIPEMD160() {
         super("PBEwithHmacRIPEMD160", (DERObjectIdentifier)null, false, 2, 2, 160, 0);
      }
   }

   public static class PBEWithSHA extends PBEKeyFactory {
      public PBEWithSHA() {
         super("PBEwithHmacSHA", (DERObjectIdentifier)null, false, 2, 1, 160, 0);
      }
   }

   public static class PBEWithSHA1AndDES extends PBEKeyFactory {
      public PBEWithSHA1AndDES() {
         super("PBEwithSHA1andDES", PKCSObjectIdentifiers.pbeWithSHA1AndDES_CBC, true, 0, 1, 64, 64);
      }
   }

   public static class PBEWithSHA1AndRC2 extends PBEKeyFactory {
      public PBEWithSHA1AndRC2() {
         super("PBEwithSHA1andRC2", PKCSObjectIdentifiers.pbeWithSHA1AndRC2_CBC, true, 0, 1, 64, 64);
      }
   }

   public static class PBEWithSHA256And128BitAESBC extends PBEKeyFactory {
      public PBEWithSHA256And128BitAESBC() {
         super("PBEWithSHA256And128BitAES-CBC-BC", (DERObjectIdentifier)null, true, 2, 4, 128, 128);
      }
   }

   public static class PBEWithSHA256And192BitAESBC extends PBEKeyFactory {
      public PBEWithSHA256And192BitAESBC() {
         super("PBEWithSHA256And192BitAES-CBC-BC", (DERObjectIdentifier)null, true, 2, 4, 192, 128);
      }
   }

   public static class PBEWithSHA256And256BitAESBC extends PBEKeyFactory {
      public PBEWithSHA256And256BitAESBC() {
         super("PBEWithSHA256And256BitAES-CBC-BC", (DERObjectIdentifier)null, true, 2, 4, 256, 128);
      }
   }

   public static class PBEWithSHAAnd128BitAESBC extends PBEKeyFactory {
      public PBEWithSHAAnd128BitAESBC() {
         super("PBEWithSHA1And128BitAES-CBC-BC", (DERObjectIdentifier)null, true, 2, 1, 128, 128);
      }
   }

   public static class PBEWithSHAAnd128BitRC2 extends PBEKeyFactory {
      public PBEWithSHAAnd128BitRC2() {
         super("PBEwithSHAand128BitRC2-CBC", PKCSObjectIdentifiers.pbeWithSHAAnd128BitRC2_CBC, true, 2, 1, 128, 64);
      }
   }

   public static class PBEWithSHAAnd128BitRC4 extends PBEKeyFactory {
      public PBEWithSHAAnd128BitRC4() {
         super("PBEWithSHAAnd128BitRC4", PKCSObjectIdentifiers.pbeWithSHAAnd128BitRC4, true, 2, 1, 128, 0);
      }
   }

   public static class PBEWithSHAAnd192BitAESBC extends PBEKeyFactory {
      public PBEWithSHAAnd192BitAESBC() {
         super("PBEWithSHA1And192BitAES-CBC-BC", (DERObjectIdentifier)null, true, 2, 1, 192, 128);
      }
   }

   public static class PBEWithSHAAnd256BitAESBC extends PBEKeyFactory {
      public PBEWithSHAAnd256BitAESBC() {
         super("PBEWithSHA1And256BitAES-CBC-BC", (DERObjectIdentifier)null, true, 2, 1, 256, 128);
      }
   }

   public static class PBEWithSHAAnd40BitRC2 extends PBEKeyFactory {
      public PBEWithSHAAnd40BitRC2() {
         super("PBEwithSHAand40BitRC2-CBC", PKCSObjectIdentifiers.pbewithSHAAnd40BitRC2_CBC, true, 2, 1, 40, 64);
      }
   }

   public static class PBEWithSHAAnd40BitRC4 extends PBEKeyFactory {
      public PBEWithSHAAnd40BitRC4() {
         super("PBEWithSHAAnd128BitRC4", PKCSObjectIdentifiers.pbeWithSHAAnd128BitRC4, true, 2, 1, 40, 0);
      }
   }

   public static class PBEWithSHAAndDES2Key extends PBEKeyFactory {
      public PBEWithSHAAndDES2Key() {
         super("PBEwithSHAandDES2Key-CBC", PKCSObjectIdentifiers.pbeWithSHAAnd2_KeyTripleDES_CBC, true, 2, 1, 128, 64);
      }
   }

   public static class PBEWithSHAAndDES3Key extends PBEKeyFactory {
      public PBEWithSHAAndDES3Key() {
         super("PBEwithSHAandDES3Key-CBC", PKCSObjectIdentifiers.pbeWithSHAAnd3_KeyTripleDES_CBC, true, 2, 1, 192, 64);
      }
   }

   public static class PBEWithSHAAndIDEA extends PBEKeyFactory {
      public PBEWithSHAAndIDEA() {
         super("PBEwithSHAandIDEA-CBC", (DERObjectIdentifier)null, true, 2, 1, 128, 64);
      }
   }

   public static class PBEWithSHAAndTwofish extends PBEKeyFactory {
      public PBEWithSHAAndTwofish() {
         super("PBEwithSHAandTwofish-CBC", (DERObjectIdentifier)null, true, 2, 1, 256, 128);
      }
   }

   public static class PBEWithTiger extends PBEKeyFactory {
      public PBEWithTiger() {
         super("PBEwithHmacTiger", (DERObjectIdentifier)null, false, 2, 3, 192, 0);
      }
   }
}
